@@ -47,7 +47,7 @@
 #' @seealso \Sexpr[stage=render,results=rd]{parsnip:::make_seealso_list("boost_tree")},
 #' [xgb_train()], [C5.0_train()]
 #'
-#' @examples
+#' @examplesIf !parsnip:::is_cran_check()
 #' show_engines("boost_tree")
 #'
 #' boost_tree(mode = "classification", trees = 20)
@@ -435,15 +435,22 @@ as_xgb_data <- function(x, y, validation = 0, weights = NULL, event_level = "fir
       # Split data
       m <- floor(n * (1 - validation)) + 1
       trn_index <- sample(seq_len(n), size = max(m, 2))
-      val_data <- xgboost::xgb.DMatrix(x[-trn_index,], label = y[-trn_index], missing = NA)
+      val_data <- xgboost::xgb.DMatrix(
+        data = x[-trn_index, , drop = FALSE],
+        label = y[-trn_index],
+        missing = NA
+      )
       watch_list <- list(validation = val_data)
 
       info_list <- list(label = y[trn_index])
       if (!is.null(weights)) {
         info_list$weight <- weights[trn_index]
       }
-      dat <- xgboost::xgb.DMatrix(x[trn_index,], missing = NA, info = info_list)
-
+      dat <- xgboost::xgb.DMatrix(
+        data = x[trn_index, , drop = FALSE],
+        missing = NA,
+        info = info_list
+      )
 
     } else {
       info_list <- list(label = y)
