@@ -25,7 +25,7 @@ ctrl <- control_parsnip(verbosity = 0, catch = FALSE)
 test_that('model fitting', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   set_tf_seed(257)
 
@@ -95,7 +95,7 @@ test_that('model fitting', {
 test_that('classification prediction', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   library(keras)
 
@@ -140,7 +140,7 @@ test_that('classification prediction', {
 test_that('classification probabilities', {
   skip_on_cran()
   skip_if_not_installed("keras")
-  skip_if(is.null(tensorflow::tf_version()))
+  skip_if(!is_tf_ok())
 
   library(keras)
 
